import {
  executeTemplate,
  buildFixture,
} from "@constructor-io/constructorio-connect-cli";

describe("item", () => {
  it("should match inline snapshot", async () => {
    /**
     * Add a function `executeTemplate` which abstracts all the complexity from
     * running a template and gives you the result back.
     *
     * It will:
     * - Load the template.
     * - Receive the fixture + externalData (optional) as an object.
     * - Automatically load the first `connectionId` to send to the backend.
     * - Execute the template on the backend.
     * - Return an object.
     *
     * In failure:
     * - It will throw an error, not allowing the test to proceed.
     */
    const result = await executeTemplate({
      // Define the template type: item | variation | item_group | mapping | grouping
      type: "item",

      // Define the template file name, which will be used to load the test
      name: "item.jsonata",

      /**
       * Add a function `buildFixture` to load a fixture from a type and file name.
       * It can also receive a second param being an object, which will deep merge into
       * the fixture itself - similarly to how a factory pattern works. This way we can
       * have only one fixture with many tests :)
       */
      fixture: buildFixture("item", "item.json", {
        name: "other shoes!",
        variations: [
          {
            name: "other shoes (red)",
            price: 130,
          },
          {
            name: "other shoes (blue)",
            price: 200,
          },
        ],
      }),
    });

    // Alternatively, you can also store the snapshot in a file to reduce clutter.
    // expect(result).toMatchSnapshot();

    expect(result).toMatchInlineSnapshot(`
{
  "facets": [
    {
      "key": "price_average",
      "value": 165,
    },
  ],
  "item_name": "These are my other shoes!!",
  "metadata": [
    {
      "key": "colors",
    },
  ],
}
`);
  });

  it("should compute the average price", async () => {
    const response = await executeTemplate({
      type: "item",
      name: "item.jsonata",
      fixture: buildFixture("item", "item.json", {
        variations: [{ price: 100 }, { price: 200 }],
      }),
    });

    const priceFacet = response.facets.find(
      (facet) => facet.key === "price_average",
    );

    expect(priceFacet.value).toBe(150);
  });
});
