"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const core_1 = require("@oclif/core");
const fs_extra_1 = require("fs-extra");
const prompts_1 = require("@inquirer/prompts");
const ux_action_1 = require("../helpers/ux-action");
const render_tip_1 = require("../rendering/render-tip");
const render_prompt_1 = require("../prompt-data/render-prompt");
const types_1 = require("../types");
const get_fixture_1 = require("../http/get-fixture");
const get_connections_request_1 = require("../http/get-connections-request");
const file_exists_1 = require("../helpers/file-exists");
const path_2 = require("../customer/path");
class GenerateFixture extends core_1.Command {
    static args = {};
    static description = `
This command will fetch one fixture from the server and save it into a specified file. This fixture file will be an example of how the data would be passed to the connector when executing the templates.\n
You are expected to customize this file to match the data you expect to cover in a template execution (e.g. an item with stock, a variation with missing data), etc. Note that you can have multiple fixtures of the same type to cover different scenarios.\n
Finally, if the file already exists you'll be prompted to overwrite it.
  `;
    static examples = ["$ <%= config.bin %> generate-fixture"];
    async run() {
        const connections = await (0, ux_action_1.uxAction)("📡 Reading your connections...", async () => {
            return await (0, get_connections_request_1.getConnections)({ showLogs: true });
        })();
        const connectionId = await (0, render_prompt_1.renderPrompt)({
            promptMessage: "Choose the connection to generate the fixture for",
            choices: connections.map((connection) => ({
                name: `[${connection.environment}] - ${connection.name} `,
                value: connection.id,
            })),
        });
        const type = await (0, render_prompt_1.renderPrompt)({
            promptMessage: "Choose the type of fixture you want to generate",
            choices: Object.keys(types_1.CatalogFixtureType).map((catalogFixtureType) => ({
                name: catalogFixtureType,
                value: Object(types_1.CatalogFixtureType)[catalogFixtureType],
            })),
        });
        const filename = await (0, prompts_1.input)({
            message: "Enter the filename",
            default: `${type}.json`,
        });
        const filepath = this.getFixturePath(type, filename);
        const shouldAskReplace = (0, file_exists_1.fileExists)(filepath, true);
        if (shouldAskReplace) {
            const shouldRefresh = await (0, prompts_1.confirm)({
                message: `This fixture already exists. Do you want to refresh it?`,
                default: false,
            });
            if (!shouldRefresh) {
                (0, render_tip_1.renderTip)([
                    "Your file was not refreshed!",
                    "If you want to generate the fixture, please execute the command again",
                ]);
                return;
            }
        }
        try {
            await (0, ux_action_1.uxAction)("🧶 Generating fixtures...", async () => {
                const response = await (0, get_fixture_1.getFixture)({
                    connectionId,
                    type: type,
                });
                await (0, fs_extra_1.outputFile)(filepath, JSON.stringify(response.data, null, 2));
            })();
            core_1.ux.info(`🎉 ${type} fixture generated at ${filepath}`);
        }
        catch (err) {
            core_1.ux.error(`🙈 ${err.message}`);
        }
    }
    getFixturePath(type, filename) {
        return (0, path_2.getCustomerPath)(path_1.default.join("src", "fixtures", type, filename.replace(/\.[^/.]+$/, "") + ".json"));
    }
}
exports.default = GenerateFixture;
